/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

export class Monitor {
  id!: number;
  name!: string;
  app!: string;
  scrape!: string;
  instance!: string;
  intervals: number = 60;
  // Schedule type: interval | cron
  scheduleType: string = 'interval';
  // Cron expression when scheduleType is cron
  cronExpression?: string;
  // Monitoring status 0: Paused, 1: Up, 2: Down
  status!: number;
  // Task type 0: Normal, 1: push auto create, 2: discovery auto create
  type!: number;
  description!: string;
  labels!: Record<string, string>;
  annotations!: Record<string, string>;
  creator!: string;
  modifier!: string;
  gmtCreate!: number;
  gmtUpdate!: number;

  _displayStatus?: 'ACTIVE' | 'DISAPPEARED' | 'GRACE_PERIOD';
  _graceTimer?: any;
  _disappearTime?: number;
}
